Logic functions
***************

.. currentmodule:: numpy

Truth value testing
-------------------
.. autosummary::
   :toctree: generated/

   all
   any

Array contents
--------------
.. autosummary::
   :toctree: generated/

   isfinite
   isinf
   isnan
   isneginf
   isposinf

Array type testing
------------------
.. autosummary::
   :toctree: generated/

   iscomplex
   iscomplexobj
   isfortran
   isreal
   isrealobj
   isscalar

Logical operations
------------------
.. autosummary::
   :toctree: generated/

   logical_and
   logical_or
   logical_not
   logical_xor

Comparison
----------
.. autosummary::
   :toctree: generated/

   allclose
   isclose
   array_equal
   array_equiv

.. autosummary::
   :toctree: generated/

   greater
   greater_equal
   less
   less_equal
   equal
   not_equal
